@@ -11,7 +11,7 @@
  * GNSS-SDR is a Global Navigation Satellite System software-defined receiver.
  * This file is part of GNSS-SDR.
  *
- * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
+ * Copyright (C) 2010-2022  (see AUTHORS file for a list of contributors)
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * -----------------------------------------------------------------------------
@@ -22,9 +22,7 @@
 #include "configuration_interface.h"
 #include "gnss_sdr_fft.h"
 #include "gnss_sdr_flags.h"
-#include "gnss_synchro.h"
 #include "gps_l2c_signal_replica.h"
-#include "uio_fpga.h"
 #include <glog/logging.h>
 #include <gnuradio/gr_complex.h>  // for gr_complex
 #include <volk/volk.h>            // for volk_32fc_conjugate_32fc
@@ -45,47 +43,20 @@ GpsL2MPcpsAcquisitionFpga::GpsL2MPcpsAcquisitionFpga(
                                 in_streams_(in_streams),
                                 out_streams_(out_streams)
 {
-    pcpsconf_fpga_t acq_parameters;
-    std::string default_dump_filename = "./acquisition.mat";
+    acq_parameters_.SetFromConfiguration(configuration, role, fpga_downsampling_factor, fpga_buff_num, fpga_blk_exp, GPS_L2_M_CODE_RATE_CPS, GPS_L2_M_CODE_LENGTH_CHIPS);
 
     LOG(INFO) << "role " << role;
 
-    int64_t fs_in_deprecated = configuration->property("GNSS-SDR.internal_fs_hz", 2048000);
-    fs_in_ = configuration->property("GNSS-SDR.internal_fs_sps", fs_in_deprecated);
-    acq_parameters.fs_in = fs_in_;
-
-    acq_parameters.repeat_satellite = configuration->property(role + ".repeat_satellite", false);
-    DLOG(INFO) << role << " satellite repeat = " << acq_parameters.repeat_satellite;
-
-    doppler_max_ = configuration->property(role + ".doppler_max", 5000);
     if (FLAGS_doppler_max != 0)
         {
-            doppler_max_ = FLAGS_doppler_max;
+            acq_parameters_.doppler_max = FLAGS_doppler_max;
         }
-    acq_parameters.doppler_max = doppler_max_;
+    doppler_max_ = acq_parameters_.doppler_max;
+    doppler_step_ = static_cast<unsigned int>(acq_parameters_.doppler_step);
+    fs_in_ = acq_parameters_.fs_in;
 
-    auto code_length = static_cast<unsigned int>(std::round(static_cast<double>(fs_in_) / (GPS_L2_M_CODE_RATE_CPS / static_cast<double>(GPS_L2_M_CODE_LENGTH_CHIPS))));
-    acq_parameters.code_length = code_length;
-    // The FPGA can only use FFT lengths that are a power of two.
-    float nbits = ceilf(log2f(static_cast<float>(code_length)));
-    unsigned int nsamples_total = pow(2, nbits);
-    unsigned int select_queue_Fpga = configuration->property(role + ".select_queue_Fpga", 0);
-    acq_parameters.select_queue_Fpga = select_queue_Fpga;
-
-    // UIO device file
-    std::string device_io_name;
-    // find the uio device file corresponding to the acquisition
-    if (find_uio_dev_file_name(device_io_name, acquisition_device_name, 0) < 0)
-        {
-            std::cout << "Cannot find the FPGA uio device file corresponding to device name " << acquisition_device_name << std::endl;
-            throw std::exception();
-        }
-    acq_parameters.device_name = device_io_name;
-
-    acq_parameters.samples_per_code = nsamples_total;
-    acq_parameters.downsampling_factor = configuration->property(role + ".downsampling_factor", 1.0);
-    acq_parameters.total_block_exp = configuration->property(role + ".total_block_exp", 14);
-    acq_parameters.excludelimit = static_cast<uint32_t>(std::round(static_cast<double>(fs_in_) / GPS_L2_M_CODE_RATE_CPS));
+    uint32_t code_length = acq_parameters_.code_length;
+    uint32_t nsamples_total = acq_parameters_.samples_per_code;
 
     // compute all the GPS L2C PRN Codes (this is done only once upon the class constructor in order to avoid re-computing the PRN codes every time
     // a channel is assigned)
@@ -139,15 +110,9 @@ GpsL2MPcpsAcquisitionFpga::GpsL2MPcpsAcquisitionFpga(
                 }
         }
 
-    acq_parameters.all_fft_codes = d_all_fft_codes_.data();
+    acq_parameters_.all_fft_codes = d_all_fft_codes_.data();
 
-    acquisition_fpga_ = pcps_make_acquisition_fpga(acq_parameters);
-
-    channel_ = 0;
-    doppler_step_ = 0;
-    gnss_synchro_ = nullptr;
-
-    threshold_ = 0.0;
+    acquisition_fpga_ = pcps_make_acquisition_fpga(acq_parameters_);
 
     if (in_streams_ > 1)
         {
