@@ -11,7 +11,7 @@
  * GNSS-SDR is a Global Navigation Satellite System software-defined receiver.
  * This file is part of GNSS-SDR.
  *
- * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
+ * Copyright (C) 2010-2022  (see AUTHORS file for a list of contributors)
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * -----------------------------------------------------------------------------
@@ -20,7 +20,9 @@
 #ifndef GNSS_SDR_GPS_L2_M_PCPS_ACQUISITION_FPGA_H
 #define GNSS_SDR_GPS_L2_M_PCPS_ACQUISITION_FPGA_H
 
+#include "acq_conf_fpga.h"
 #include "channel_fsm.h"
+#include "gnss_synchro.h"
 #include "pcps_acquisition_fpga.h"
 #include <gnuradio/runtime_types.h>  // for basic_block_sptr, top_block_sptr
 #include <volk_gnsssdr/volk_gnsssdr_alloc.h>
@@ -34,7 +36,6 @@
  * \{ */
 
 
-class Gnss_Synchro;
 class ConfigurationInterface;
 
 /*!
@@ -148,7 +149,9 @@ public:
     void set_resampler_latency(uint32_t latency_samples __attribute__((unused))) override{};
 
 private:
-    const std::string acquisition_device_name = "acquisition_S00_AXI";  // UIO device name
+    static const uint32_t fpga_downsampling_factor = 4;  // downampling factor in the FPGA
+    static const uint32_t fpga_buff_num = 0;             // L2 band
+    static const uint32_t fpga_blk_exp = 13;             // default block exponent
 
     static const uint32_t NUM_PRNs = 32;
     static const uint32_t QUANT_BITS_LOCAL_CODE = 16;
@@ -161,8 +164,7 @@ private:
     volk_gnsssdr::vector<uint32_t> d_all_fft_codes_;  // memory that contains all the code ffts
     std::weak_ptr<ChannelFsm> channel_fsm_;
     Gnss_Synchro* gnss_synchro_;
-    std::string item_type_;
-    std::string dump_filename_;
+    Acq_Conf_Fpga acq_parameters_;
     std::string role_;
     int64_t fs_in_;
     float threshold_;
