@@ -9,13 +9,10 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
- *
- * GNSS-SDR is a software defined Global Navigation
- *          Satellite Systems receiver
- *
+ * GNSS-SDR is a Global Navigation Satellite System software-defined receiver.
  * This file is part of GNSS-SDR.
  *
+ * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * -----------------------------------------------------------------------------
@@ -38,6 +35,16 @@
 #include <mutex>
 #include <string>
 
+/** \addtogroup Channel
+ * Classes containing a GNSS channel.
+ * \{ */
+/** \addtogroup Channel_adapters channel_adapters
+ * Classes that wrap an AcquisitionInterface,
+ * a TrackingInterface and a TelemetryDecoderInterface, and handles
+ * their interaction.
+ * \{ */
+
+
 class ConfigurationInterface;
 class AcquisitionInterface;
 class TrackingInterface;
@@ -46,7 +53,7 @@ class TelemetryDecoderInterface;
 
 /*!
  * \brief This class represents a GNSS channel. It wraps an AcquisitionInterface,
- * a Tracking Interface and a TelemetryDecoderInterface, and handles
+ * a TrackingInterface and a TelemetryDecoderInterface, and handles
  * their interaction through a Finite State Machine
  *
  */
@@ -54,23 +61,29 @@ class Channel : public ChannelInterface
 {
 public:
     //! Constructor
-    Channel(const ConfigurationInterface* configuration, uint32_t channel, std::shared_ptr<AcquisitionInterface> acq,
-        std::shared_ptr<TrackingInterface> trk, std::shared_ptr<TelemetryDecoderInterface> nav,
-        const std::string& role, const std::string& signal_str, Concurrent_Queue<pmt::pmt_t>* queue);
+    Channel(const ConfigurationInterface* configuration,
+        uint32_t channel,
+        std::shared_ptr<AcquisitionInterface> acq,
+        std::shared_ptr<TrackingInterface> trk,
+        std::shared_ptr<TelemetryDecoderInterface> nav,
+        const std::string& role,
+        const std::string& signal_str,
+        Concurrent_Queue<pmt::pmt_t>* queue);
 
     ~Channel() = default;  //!< Destructor
 
-    void connect(gr::top_block_sptr top_block) override;  //!< connects the tracking block to the top_block and to the telemetry
+    void connect(gr::top_block_sptr top_block) override;  //!< Connects the tracking block to the top_block and to the telemetry
     void disconnect(gr::top_block_sptr top_block) override;
-    gr::basic_block_sptr get_left_block() override;      //!< gets the gnuradio tracking block pointer
-    gr::basic_block_sptr get_left_block_trk() override;  //!< gets the gnuradio tracking block pointer
-    gr::basic_block_sptr get_left_block_acq() override;  //!< gets the gnuradio tracking block pointer
-    gr::basic_block_sptr get_right_block() override;
+    gr::basic_block_sptr get_left_block() override;
+    gr::basic_block_sptr get_left_block_trk() override;   //!< Gets the GNU Radio tracking block input pointer
+    gr::basic_block_sptr get_right_block_trk() override;  //!< Gets the GNU Radio tracking block output pointer
+    gr::basic_block_sptr get_left_block_acq() override;   //!< Gets the GNU Radio acquisition block input pointer
+    gr::basic_block_sptr get_right_block_acq() override;  //!< Gets the GNU Radio acquisition block output pointer
+    gr::basic_block_sptr get_right_block() override;      //!< Gets the GNU Radio channel block output pointer
 
     inline std::string role() override { return role_; }
-    //! Returns "Channel"
-    inline std::string implementation() override { return std::string("Channel"); }
-    inline size_t item_size() override { return 0; }
+    inline std::string implementation() override { return std::string("Channel"); }  //!< Returns "Channel"
+    inline size_t item_size() override { return 2 * sizeof(float); }
     inline Gnss_Signal get_signal() const override { return gnss_signal_; }
     void start_acquisition() override;                          //!< Start the State Machine
     void stop_channel() override;                               //!< Stop the State Machine
@@ -81,9 +94,9 @@ public:
     inline std::shared_ptr<AcquisitionInterface> acquisition() const { return acq_; }
     inline std::shared_ptr<TrackingInterface> tracking() const { return trk_; }
     inline std::shared_ptr<TelemetryDecoderInterface> telemetry() const { return nav_; }
-    void msg_handler_events(pmt::pmt_t msg);
 
 private:
+    bool glonass_dll_pll_c_aid_tracking_check() const;
     std::shared_ptr<ChannelFsm> channel_fsm_;
     std::shared_ptr<AcquisitionInterface> acq_;
     std::shared_ptr<TrackingInterface> trk_;
@@ -94,9 +107,13 @@ private:
     std::string role_;
     std::mutex mx_;
     uint32_t channel_;
+    int glonass_extend_correlation_ms_;
     bool connected_;
     bool repeat_;
     bool flag_enable_fpga_;
 };
 
+
+/** \} */
+/** \} */
 #endif  // GNSS_SDR_CHANNEL_H
