@@ -22,18 +22,25 @@
  * -----------------------------------------------------------------------------
  * Copyright (C) 2007-2013, T. Takasu
  * Copyright (C) 2017, Javier Arribas
- * Copyright (C) 2017, Carles Fernandez
+ * Copyright (C) 2017-2023, Carles Fernandez
  * All rights reserved.
  *
  * SPDX-License-Identifier: BSD-2-Clause
  * -----------------------------------------------------------------------------
  */
 
+#if ARMA_NO_BOUND_CHECKING
+#define ARMA_NO_DEBUG 1
+#endif
+
 #include "rtklib_pntpos.h"
 #include "rtklib_ephemeris.h"
 #include "rtklib_ionex.h"
 #include "rtklib_sbas.h"
+#include <armadillo>
+#include <cmath>
 #include <cstring>
+#include <vector>
 
 /* pseudorange measurement error variance ------------------------------------*/
 double varerr(const prcopt_t *opt, double el, int sys)
@@ -598,6 +605,81 @@ int valsol(const double *azel, const int *vsat, int n,
 }
 
 
+// Lorentz inner product
+double lorentz(const arma::vec &x, const arma::vec &y)
+{
+    double p = x(0) * y(0) + x(1) * y(1) + x(2) * y(2) - x(3) * y(3);
+    return p;
+}
+
+
+// Bancroft method (see https://gssc.esa.int/navipedia/index.php/Bancroft_Method)
+// without travel time rotation
+arma::vec rough_bancroft(const arma::mat &B_pass)
+{
+    const int m = B_pass.n_rows;
+    arma::vec pos = arma::zeros<arma::vec>(4);
+    arma::mat BBB;
+    bool success;
+    if (m > 4)
+        {
+            success = arma::pinv(BBB, B_pass);
+        }
+    else
+        {
+            success = arma::inv(BBB, B_pass);
+        }
+    if (!success)
+        {
+            return pos;
+        }
+    const arma::vec e = arma::ones<arma::vec>(m);
+    arma::vec alpha = arma::zeros<arma::vec>(m);
+    for (int i = 0; i < m; i++)
+        {
+            arma::vec Bi = B_pass.row(i).t();
+            alpha(i) = lorentz(Bi, Bi) / 2.0;
+        }
+    const arma::vec BBBe = BBB * e;
+    const arma::vec BBBalpha = BBB * alpha;
+    const double a = lorentz(BBBe, BBBe);
+    const double b = lorentz(BBBe, BBBalpha) - 1.0;
+    const double c = lorentz(BBBalpha, BBBalpha);
+    const double root = std::sqrt(b * b - a * c);
+    arma::vec r(2);
+    r(0) = (-b - root) / a;
+    r(1) = (-b + root) / a;
+    arma::mat possible_pos = arma::zeros<arma::mat>(4, 2);
+    for (int i = 0; i < 2; i++)
+        {
+            possible_pos.col(i) = r(i) * BBBe + BBBalpha;
+            possible_pos(3, i) = -possible_pos(3, i);
+        }
+    arma::vec abs_omc(2);
+    for (int j = 0; j < m; j++)
+        {
+            for (int i = 0; i < 2; i++)
+                {
+                    const double c_dt = possible_pos(3, i);
+                    const double calc = arma::norm(B_pass.row(j).head(3).t() - possible_pos.head_rows(3).col(i)) + c_dt;
+                    const double omc = B_pass(j, 3) - calc;
+                    abs_omc(i) = std::abs(omc);
+                }
+        }
+
+    if (abs_omc(0) > abs_omc(1))
+        {
+            pos = possible_pos.col(1);
+        }
+    else
+        {
+            pos = possible_pos.col(0);
+        }
+
+    return pos;
+}
+
+
 /* estimate receiver position ------------------------------------------------*/
 int estpos(const obsd_t *obs, int n, const double *rs, const double *dts,
     const double *vare, const int *svh, const nav_t *nav,
@@ -631,6 +713,34 @@ int estpos(const obsd_t *obs, int n, const double *rs, const double *dts,
             x[i] = sol->rr[i];
         }
 
+    // Rough first estimation to initialize the algorithm
+    if (opt->bancroft_init && (std::sqrt(x[0] * x[0] + x[1] * x[1] + x[2] * x[2]) < 0.1))
+        {
+            arma::mat B = arma::mat(n, 4, arma::fill::zeros);
+            for (i = 0; i < n; i++)
+                {
+                    B(i, 0) = rs[0 + i * 6];
+                    B(i, 1) = rs[1 + i * 6];
+                    B(i, 2) = rs[2 + i * 6];
+                    if (obs[i].code[0] != CODE_NONE)
+                        {
+                            B(i, 3) = obs[i].P[0];
+                        }
+                    else if (obs[i].code[1] != CODE_NONE)
+                        {
+                            B(i, 3) = obs[i].P[1];
+                        }
+                    else
+                        {
+                            B(i, 3) = obs[i].P[2];
+                        }
+                }
+            arma::vec pos = rough_bancroft(B);
+            x[0] = pos(0);
+            x[1] = pos(1);
+            x[2] = pos(2);
+        }
+
     for (i = 0; i < MAXITR; i++)
         {
             /* pseudorange residuals */
@@ -719,7 +829,6 @@ int raim_fde(const obsd_t *obs, int n, const double *rs,
     obsd_t *obs_e;
     sol_t sol_e = {{0, 0}, {}, {}, {}, '0', '0', '0', 0.0, 0.0, 0.0};
     char tstr[32];
-    char name[16];
     char msg_e[128];
     double *rs_e;
     double *dts_e;
@@ -818,8 +927,8 @@ int raim_fde(const obsd_t *obs, int n, const double *rs,
     if (stat)
         {
             time2str(obs[0].time, tstr, 2);
-            satno2id(sat, name);
-            trace(2, "%s: %s excluded by raim\n", tstr + 11, name);
+            auto name = satno2id(sat);
+            trace(2, "%s: %s excluded by raim\n", tstr + 11, name.data());
         }
     free(obs_e);
     free(rs_e);
@@ -988,8 +1097,8 @@ int pntpos(const obsd_t *obs, int n, const nav_t *nav,
     double *resp;
     int i;
     int stat;
-    int vsat[MAXOBS] = {0};
-    int svh[MAXOBS];
+    std::vector<int> vsat(MAXOBS, 0);
+    std::vector<int> svh(MAXOBS, 0);
 
     sol->stat = SOLQ_NONE;
 
@@ -1019,20 +1128,20 @@ int pntpos(const obsd_t *obs, int n, const nav_t *nav,
             opt_.tropopt = TROPOPT_SAAS;
         }
     /* satellite positions, velocities and clocks */
-    satposs(sol->time, obs, n, nav, opt_.sateph, rs, dts, var, svh);
+    satposs(sol->time, obs, n, nav, opt_.sateph, rs, dts, var, svh.data());
 
     /* estimate receiver position with pseudorange */
-    stat = estpos(obs, n, rs, dts, var, svh, nav, &opt_, sol, azel_, vsat, resp, msg);
+    stat = estpos(obs, n, rs, dts, var, svh.data(), nav, &opt_, sol, azel_, vsat.data(), resp, msg);
 
     /* raim fde */
     if (!stat && n >= 6 && opt->posopt[4])
         {
-            stat = raim_fde(obs, n, rs, dts, var, svh, nav, &opt_, sol, azel_, vsat, resp, msg);
+            stat = raim_fde(obs, n, rs, dts, var, svh.data(), nav, &opt_, sol, azel_, vsat.data(), resp, msg);
         }
     /* estimate receiver velocity with doppler */
     if (stat)
         {
-            estvel(obs, n, rs, dts, nav, &opt_, sol, azel_, vsat);
+            estvel(obs, n, rs, dts, nav, &opt_, sol, azel_, vsat.data());
         }
 
     if (azel)
