@@ -24,6 +24,7 @@
 #include <boost/lexical_cast.hpp>
 #include <glog/logging.h>
 #include <gnuradio/io_signature.h>
+#include <algorithm>
 #include <cmath>
 #include <cuda_profiler_api.h>
 #include <iostream>
@@ -134,7 +135,11 @@ Gps_L1_Ca_Dll_Pll_Tracking_GPU_cc::Gps_L1_Ca_Dll_Pll_Tracking_GPU_cc(
     systemName["G"] = std::string("GPS");
     systemName["S"] = std::string("SBAS");
 
-    set_relative_rate(1.0 / (static_cast<double>(d_vector_length) * 2.0));
+#if GNURADIO_GREATER_THAN_38
+    this->set_relative_rate(1, static_cast<uint64_t>(d_vector_length * 2));
+#else
+    this->set_relative_rate(1.0 / static_cast<double>(d_vector_length * 2));
+#endif
 
     d_acquisition_gnss_synchro = 0;
     d_channel = 0;
@@ -277,11 +282,11 @@ void Gps_L1_Ca_Dll_Pll_Tracking_GPU_cc::set_channel(uint32_t channel)
                         {
                             d_dump_filename.append(boost::lexical_cast<std::string>(d_channel));
                             d_dump_filename.append(".dat");
-                            d_dump_file.exceptions(std::ifstream::failbit | std::ifstream::badbit);
+                            d_dump_file.exceptions(std::ofstream::failbit | std::ofstream::badbit);
                             d_dump_file.open(d_dump_filename.c_str(), std::ios::out | std::ios::binary);
                             LOG(INFO) << "Tracking dump enabled on channel " << d_channel << " Log file: " << d_dump_filename.c_str();
                         }
-                    catch (const std::ifstream::failure *e)
+                    catch (const std::ofstream::failure *e)
                         {
                             LOG(WARNING) << "channel " << d_channel << " Exception opening trk dump file " << e->what();
                         }
@@ -349,7 +354,7 @@ int Gps_L1_Ca_Dll_Pll_Tracking_GPU_cc::general_work(int noutput_items __attribut
             // ################# CARRIER WIPEOFF AND CORRELATORS ##############################
             // perform carrier wipe-off and compute Early, Prompt and Late correlation
 
-            memcpy(in_gpu, in, sizeof(gr_complex) * d_correlation_length_samples);
+            std::copy(in, in + d_correlation_length_samples, in_gpu);
             cudaProfilerStart();
             multicorrelator_gpu->Carrier_wipeoff_multicorrelator_resampler_cuda(static_cast<float>(d_rem_carrier_phase_rad),
                 static_cast<float>(d_carrier_phase_step_rad),
@@ -535,7 +540,7 @@ int Gps_L1_Ca_Dll_Pll_Tracking_GPU_cc::general_work(int noutput_items __attribut
                     uint32_t prn_ = d_acquisition_gnss_synchro->PRN;
                     d_dump_file.write(reinterpret_cast<char *>(&prn_), sizeof(uint32_t));
                 }
-            catch (const std::ifstream::failure *e)
+            catch (const std::ofstream::failure *e)
                 {
                     LOG(WARNING) << "Exception writing trk dump file " << e->what();
                 }
